@@ -2,6 +2,7 @@
 
 #include "src/standardfeed.h"
 
+#include "src/definitions.h"
 #include "src/gui/formstandardfeeddetails.h"
 #include "src/standardserviceroot.h"
 
@@ -52,7 +53,9 @@ StandardFeed::StandardFeed(RootItem* parent_item) : Feed(parent_item) {
   m_protection = NetworkFactory::NetworkAuthentication::NoAuthentication;
   m_username = QString();
   m_password = QString();
+  m_httpHeaders = {};
   m_dontUseRawXmlSaving = false;
+  m_http2Status = NetworkFactory::Http2Status::DontSet;
 }
 
 StandardFeed::StandardFeed(const StandardFeed& other) : Feed(other) {
@@ -64,6 +67,8 @@ StandardFeed::StandardFeed(const StandardFeed& other) : Feed(other) {
   m_username = other.username();
   m_password = other.password();
   m_dontUseRawXmlSaving = other.dontUseRawXmlSaving();
+  m_httpHeaders = other.httpHeaders();
+  m_http2Status = other.http2Status();
 }
 
 QList<QAction*> StandardFeed::contextMenuFeedsList() {
@@ -86,12 +91,13 @@ QString StandardFeed::additionalTooltip() const {
                      .toStdList();
   QStringList fltrs = FROM_STD_LIST(QStringList, std_fltrs);
 
-  // TODO: toto je v podstatě zkopirovane z Feed...
+  // TODO: Basically copied from base implementation.
   QString base_tooltip =
     tr("Auto-update status: %1\n"
        "Active message filters: %2\n"
        "Status: %3\n"
        "Source: %4\n"
+       "HTTP/2: %6\n"
        "Item ID: %5\n")
       .arg(getAutoUpdateStatusDescription(),
            filters.size() > 0 ? QSL("%1 (%2)").arg(QString::number(filters.size()), fltrs.join(QSL(", ")))
@@ -99,7 +105,8 @@ QString StandardFeed::additionalTooltip() const {
            stat,
            m_sourceType == SourceType::Url ? QString("<a href=\"%1\">%1</a>").arg(source().left(100))
                                            : source().left(100),
-           customId());
+           customId(),
+           getHttpDescription());
 
   return base_tooltip + tr("Encoding: %1\n"
                            "Type: %2\n"
@@ -111,6 +118,14 @@ QString StandardFeed::additionalTooltip() const {
                                !dontUseRawXmlSaving() ? tr("yes") : tr("no"));
 }
 
+NetworkFactory::Http2Status StandardFeed::http2Status() const {
+  return m_http2Status;
+}
+
+void StandardFeed::setHttp2Status(NetworkFactory::Http2Status status) {
+  m_http2Status = status;
+}
+
 bool StandardFeed::canBeDeleted() const {
   return true;
 }
@@ -164,6 +179,8 @@ QVariantHash StandardFeed::customDatabaseData() const {
   data[QSL("username")] = username();
   data[QSL("password")] = TextFactory::encrypt(password());
   data[QSL("dont_use_raw_xml_saving")] = dontUseRawXmlSaving();
+  data[QSL("http_headers")] = httpHeaders();
+  data[QSL("http2_status")] = int(http2Status());
 
   return data;
 }
@@ -177,6 +194,8 @@ void StandardFeed::setCustomDatabaseData(const QVariantHash& data) {
   setUsername(data[QSL("username")].toString());
   setPassword(TextFactory::decrypt(data[QSL("password")].toString()));
   setDontUseRawXmlSaving(data[QSL("dont_use_raw_xml_saving")].toBool());
+  setHttpHeaders(data[QSL("http_headers")].toHash());
+  setHttp2Status(NetworkFactory::Http2Status(data[QSL("http2_status")].toInt()));
 }
 
 QString StandardFeed::typeToString(StandardFeed::Type type) {
@@ -226,23 +245,29 @@ QString StandardFeed::sourceTypeToString(StandardFeed::SourceType type) {
 
 void StandardFeed::fetchMetadataForItself() {
   try {
-    StandardFeed* metadata = guessFeed(sourceType(),
-                                       source(),
-                                       postProcessScript(),
-                                       protection(),
-                                       true,
-                                       username(),
-                                       password(),
-                                       getParentServiceRoot()->networkProxy());
+    auto metadata = guessFeed(sourceType(),
+                              source(),
+                              postProcessScript(),
+                              serviceRoot(),
+                              protection(),
+                              true,
+                              username(),
+                              password(),
+                              {},
+                              getParentServiceRoot()->networkProxy());
 
     // Copy metadata to our object.
-    setTitle(metadata->title());
-    setDescription(metadata->description());
-    setType(metadata->type());
-    setEncoding(metadata->encoding());
-    setIcon(metadata->icon());
+    setTitle(metadata.first->title());
+    setDescription(metadata.first->description());
+    setType(metadata.first->type());
+    setEncoding(metadata.first->encoding());
+    setIcon(metadata.first->icon());
 
-    metadata->deleteLater();
+    if (metadata.second.m_url.isValid()) {
+      setSource(metadata.second.m_url.toString());
+    }
+
+    metadata.first->deleteLater();
 
     QSqlDatabase database = qApp->database()->driver()->connection(metaObject()->className());
 
@@ -274,34 +299,42 @@ void StandardFeed::setSourceType(SourceType source_type) {
   m_sourceType = source_type;
 }
 
-StandardFeed* StandardFeed::guessFeed(StandardFeed::SourceType source_type,
-                                      const QString& source,
-                                      const QString& post_process_script,
-                                      NetworkFactory::NetworkFactory::NetworkAuthentication protection,
-                                      bool fetch_icons,
-                                      const QString& username,
-                                      const QString& password,
-                                      const QNetworkProxy& custom_proxy) {
+QPair<StandardFeed*, NetworkResult> StandardFeed::guessFeed(StandardFeed::SourceType source_type,
+                                                            const QString& source,
+                                                            const QString& post_process_script,
+                                                            StandardServiceRoot* account,
+                                                            NetworkFactory::NetworkFactory::NetworkAuthentication
+                                                              protection,
+                                                            bool fetch_icons,
+                                                            const QString& username,
+                                                            const QString& password,
+                                                            const QList<QPair<QByteArray, QByteArray>>& http_headers,
+                                                            const QNetworkProxy& custom_proxy,
+                                                            NetworkFactory::Http2Status http2_status) {
   auto timeout = qApp->settings()->value(GROUP(Feeds), SETTING(Feeds::UpdateTimeout)).toInt();
   QByteArray feed_contents;
-  QString content_type;
+  NetworkResult network_result;
 
   if (source_type == StandardFeed::SourceType::Url) {
-    QList<QPair<QByteArray, QByteArray>> headers = {
-      NetworkFactory::generateBasicAuthHeader(protection, username, password)};
-    NetworkResult network_result =
-      NetworkFactory::performNetworkOperation(source,
-                                              timeout,
-                                              QByteArray(),
-                                              feed_contents,
-                                              QNetworkAccessManager::Operation::GetOperation,
-                                              headers,
-                                              false,
-                                              {},
-                                              {},
-                                              custom_proxy);
+    QString host = QUrl(source).host();
+    account->spaceHost(host, source);
 
-    content_type = network_result.m_contentType;
+    QList<QPair<QByteArray, QByteArray>> headers = http_headers;
+    headers << NetworkFactory::generateBasicAuthHeader(protection, username, password);
+
+    network_result = NetworkFactory::performNetworkOperation(source,
+                                                             timeout,
+                                                             QByteArray(),
+                                                             feed_contents,
+                                                             QNetworkAccessManager::Operation::GetOperation,
+                                                             headers,
+                                                             false,
+                                                             {},
+                                                             {},
+                                                             custom_proxy,
+                                                             http2_status);
+
+    // account->resetHostSpacing(host);
 
     if (network_result.m_networkError != QNetworkReply::NetworkError::NoError) {
       throw NetworkException(network_result.m_networkError);
@@ -318,7 +351,8 @@ StandardFeed* StandardFeed::guessFeed(StandardFeed::SourceType source_type,
     feed_contents = IOFactory::readFile(source);
   }
   else {
-    qDebugNN << LOGSEC_CORE << "Running custom script for guessing" << QUOTE_W_SPACE(source) << "to obtain feed data.";
+    qDebugNN << LOGSEC_STANDARD << "Running custom script for guessing" << QUOTE_W_SPACE(source)
+             << "to obtain feed data.";
 
     // Use script to generate feed file.
     feed_contents = generateFeedFileWithScript(source, timeout);
@@ -329,7 +363,7 @@ StandardFeed* StandardFeed::guessFeed(StandardFeed::SourceType source_type,
   // stuff kicks in.
   if (SitemapParser::isGzip(feed_contents)) {
 #if defined(ENABLE_COMPRESSED_SITEMAP)
-    qWarningNN << LOGSEC_CORE << "Decompressing gzipped feed data.";
+    qWarningNN << LOGSEC_STANDARD << "Decompressing gzipped feed data.";
 
     QByteArray uncompressed_feed_contents;
 
@@ -339,12 +373,12 @@ StandardFeed* StandardFeed::guessFeed(StandardFeed::SourceType source_type,
 
     feed_contents = uncompressed_feed_contents;
 #else
-    qWarningNN << LOGSEC_CORE << "This feed is gzipped.";
+    qWarningNN << LOGSEC_STANDARD << "This feed is gzipped.";
 #endif
   }
 
   if (!post_process_script.simplified().isEmpty()) {
-    qDebugNN << LOGSEC_CORE << "Post-processing obtained feed data with custom script for guessing"
+    qDebugNN << LOGSEC_STANDARD << "Post-processing obtained feed data with custom script for guessing"
              << QUOTE_W_SPACE_DOT(post_process_script);
     feed_contents = postProcessFeedFileWithScript(post_process_script, feed_contents, timeout);
   }
@@ -362,7 +396,7 @@ StandardFeed* StandardFeed::guessFeed(StandardFeed::SourceType source_type,
 
   for (const QSharedPointer<FeedParser>& parser : parsers) {
     try {
-      QPair<StandardFeed*, QList<IconLocation>> res = parser->guessFeed(feed_contents, content_type);
+      QPair<StandardFeed*, QList<IconLocation>> res = parser->guessFeed(feed_contents, network_result);
 
       feed = res.first;
       icon_possible_locations = res.second;
@@ -375,7 +409,7 @@ StandardFeed* StandardFeed::guessFeed(StandardFeed::SourceType source_type,
       throw format_ex;
     }
     catch (const ApplicationException& ex) {
-      qWarningNN << LOGSEC_CORE << "Feed guessing error:" << QUOTE_W_SPACE_DOT(ex.message());
+      qWarningNN << LOGSEC_STANDARD << "Feed guessing error:" << QUOTE_W_SPACE_DOT(ex.message());
     }
   }
 
@@ -392,14 +426,17 @@ StandardFeed* StandardFeed::guessFeed(StandardFeed::SourceType source_type,
     // Try to obtain icon.
     QPixmap icon_data;
 
-    if (NetworkFactory::downloadIcon(icon_possible_locations, DOWNLOAD_TIMEOUT, icon_data, {}, custom_proxy) ==
-        QNetworkReply::NetworkError::NoError) {
+    if (NetworkFactory::downloadIcon(icon_possible_locations,
+                                     DOWNLOAD_TIMEOUT,
+                                     icon_data,
+                                     http_headers,
+                                     custom_proxy) == QNetworkReply::NetworkError::NoError) {
       // Icon for feed was downloaded and is stored now in icon_data.
       feed->setIcon(icon_data);
     }
   }
 
-  return feed;
+  return {feed, network_result};
 }
 
 Qt::ItemFlags StandardFeed::additionalFlags() const {
@@ -433,6 +470,27 @@ bool StandardFeed::removeItself() {
   return DatabaseQueries::deleteFeed(database, this, getParentServiceRoot()->accountId());
 }
 
+QString StandardFeed::getHttpDescription() const {
+  switch (m_http2Status) {
+    case NetworkFactory::Http2Status::DontSet:
+      return tr("uses application setting");
+
+    case NetworkFactory::Http2Status::Enabled:
+      return tr("enabled");
+
+    case NetworkFactory::Http2Status::Disabled:
+      return tr("disabled");
+  }
+}
+
+QVariantHash StandardFeed::httpHeaders() const {
+  return m_httpHeaders;
+}
+
+void StandardFeed::setHttpHeaders(const QVariantHash& http_headers) {
+  m_httpHeaders = http_headers;
+}
+
 bool StandardFeed::dontUseRawXmlSaving() const {
   return m_dontUseRawXmlSaving;
 }
@@ -520,7 +578,7 @@ QByteArray StandardFeed::runScriptProcess(const QStringList& cmd_args,
     auto raw_error = process.readAllStandardError();
 
     if (!raw_error.simplified().isEmpty()) {
-      qWarningNN << LOGSEC_CORE
+      qWarningNN << LOGSEC_STANDARD
                  << "Received error output from "
                     "custom script even if it "
                     "reported that it exited "
@@ -547,6 +605,16 @@ QByteArray StandardFeed::runScriptProcess(const QStringList& cmd_args,
   }
 }
 
+QList<QPair<QByteArray, QByteArray>> StandardFeed::httpHeadersToList(const QVariantHash& headers) {
+  QList<QPair<QByteArray, QByteArray>> hdrs_list;
+
+  for (auto i = headers.cbegin(), end = headers.cend(); i != end; i++) {
+    hdrs_list.append({i.key().toLocal8Bit(), i.value().toString().toLocal8Bit()});
+  }
+
+  return hdrs_list;
+}
+
 QByteArray StandardFeed::generateFeedFileWithScript(const QString& execution_line, int run_timeout) {
   auto prepared_query = prepareExecutionLine(execution_line);
 
