@@ -19,9 +19,11 @@ using RootItemPtr = RootItem*;
 
 FeedsProxyModel::FeedsProxyModel(FeedsModel* source_model, QObject* parent)
   : QSortFilterProxyModel(parent), m_sourceModel(source_model), m_view(nullptr), m_selectedItem(nullptr),
-    m_showUnreadOnly(false), m_sortAlphabetically(false) {
+    m_sortAlphabetically(false), m_filter(FeedListFilter::NoFiltering) {
   setObjectName(QSL("FeedsProxyModel"));
 
+  initializeFilters();
+
   setSortRole(Qt::ItemDataRole::EditRole);
   setSortCaseSensitivity(Qt::CaseSensitivity::CaseInsensitive);
   setRecursiveFilteringEnabled(true);
@@ -397,6 +399,54 @@ bool FeedsProxyModel::filterAcceptsRow(int source_row, const QModelIndex& source
   return should_show;
 }
 
+void FeedsProxyModel::initializeFilters() {
+  m_filters[FeedListFilter::ShowEmpty] = [this](const RootItem* item) {
+    return item->countOfAllMessages() == 0;
+  };
+
+  m_filters[FeedListFilter::ShowNonEmpty] = [this](const RootItem* item) {
+    return item->countOfAllMessages() != 0;
+  };
+
+  m_filters[FeedListFilter::ShowQuiet] = [this](const RootItem* item) {
+    Feed* feed = item->toFeed();
+
+    return feed == nullptr || feed->isQuiet();
+  };
+
+  m_filters[FeedListFilter::ShowSwitchedOff] = [this](const RootItem* item) {
+    Feed* feed = item->toFeed();
+
+    return feed == nullptr || feed->isSwitchedOff();
+  };
+
+  m_filters[FeedListFilter::ShowUnread] = [this](const RootItem* item) {
+    return item->countOfUnreadMessages() > 0;
+  };
+
+  m_filters[FeedListFilter::ShowWithArticleFilters] = [this](const RootItem* item) {
+    Feed* feed = item->toFeed();
+
+    return feed == nullptr || !feed->messageFilters().isEmpty();
+  };
+
+  m_filters[FeedListFilter::ShowWithError] = [this](const RootItem* item) {
+    Feed* feed = item->toFeed();
+
+    return feed == nullptr || feed->status() == Feed::Status::AuthError ||
+           feed->status() == Feed::Status::NetworkError || feed->status() == Feed::Status::OtherError ||
+           feed->status() == Feed::Status::ParsingError;
+  };
+
+  m_filters[FeedListFilter::ShowWithNewArticles] = [this](const RootItem* item) {
+    Feed* feed = item->toFeed();
+
+    return feed == nullptr || feed->status() == Feed::Status::NewMessages;
+  };
+
+  m_filterKeys = m_filters.keys();
+}
+
 bool FeedsProxyModel::filterAcceptsRowInternal(int source_row, const QModelIndex& source_parent) const {
   const QModelIndex idx = m_sourceModel->index(source_row, 0, source_parent);
 
@@ -406,6 +456,10 @@ bool FeedsProxyModel::filterAcceptsRowInternal(int source_row, const QModelIndex
 
   const RootItem* item = m_sourceModel->itemForIndex(idx);
 
+  if (m_selectedItem == item) {
+    return true;
+  }
+
   if (item->kind() == RootItem::Kind::Important && !item->getParentServiceRoot()->nodeShowImportant()) {
     return false;
   }
@@ -428,22 +482,29 @@ bool FeedsProxyModel::filterAcceptsRowInternal(int source_row, const QModelIndex
     return true;
   }
 
-  if (!m_showUnreadOnly) {
-    // Take only regexp filtering into account.
-    return QSortFilterProxyModel::filterAcceptsRow(source_row, source_parent);
+  bool should_show = QSortFilterProxyModel::filterAcceptsRow(source_row, source_parent);
+
+  // if (item->kind() == RootItem::Kind::Feed) {
+  //   const Feed* feed = item->toFeed();
+
+  for (FeedListFilter val : m_filterKeys) {
+    if (Globals::hasFlag(m_filter, val)) {
+      // This particular filter is enabled.
+      if (m_filters[val](item)) {
+        // The item matches the feed filter.
+        // Display it if it matches internal string-based filter too.
+        return should_show;
+      }
+    }
   }
-  else {
-    // NOTE: If item has < 0 of unread messages it may mean, that the count
-    // of unread messages is not (yet) known, display that item too.
-    //
-    // Also, the actual selected item should not be filtered out too.
-    // This is primarily to make sure that the selection does not "vanish", this
-    // particularly manifests itself if user uses "next unread item" action and
-    // "show unread only" is enabled too and user for example selects last unread
-    // article in a feed -> then the feed would disappear from list suddenly.
-    return m_selectedItem == item ||
-           (item->countOfUnreadMessages() != 0 && QSortFilterProxyModel::filterAcceptsRow(source_row, source_parent));
+
+  if (m_filter != FeedListFilter::NoFiltering) {
+    // Some filter is enabled but this item does not meet it.
+    return false;
   }
+  //}
+
+  return should_show;
 }
 
 bool FeedsProxyModel::sortAlphabetically() const {
@@ -466,23 +527,6 @@ void FeedsProxyModel::setSelectedItem(const RootItem* selected_item) {
   m_selectedItem = selected_item;
 }
 
-bool FeedsProxyModel::showUnreadOnly() const {
-  return m_showUnreadOnly;
-}
-
-void FeedsProxyModel::invalidateReadFeedsFilter(bool set_new_value, bool show_unread_only) {
-  if (set_new_value) {
-    setShowUnreadOnly(show_unread_only);
-  }
-
-  QTimer::singleShot(0, this, &FeedsProxyModel::invalidateFilter);
-}
-
-void FeedsProxyModel::setShowUnreadOnly(bool show_unread_only) {
-  m_showUnreadOnly = show_unread_only;
-  qApp->settings()->setValue(GROUP(Feeds), Feeds::ShowOnlyUnreadFeeds, show_unread_only);
-}
-
 void FeedsProxyModel::setSortAlphabetically(bool sort_alphabetically) {
   if (sort_alphabetically != m_sortAlphabetically) {
     m_sortAlphabetically = sort_alphabetically;
@@ -500,3 +544,13 @@ QModelIndexList FeedsProxyModel::mapListToSource(const QModelIndexList& indexes)
 
   return source_indexes;
 }
+
+void FeedsProxyModel::setFeedListFilter(FeedListFilter filter) {
+  m_filter = filter;
+
+#if QT_VERSION_MAJOR == 5
+  invalidateFilter();
+#else
+  invalidateRowsFilter();
+#endif
+}
