@@ -83,17 +83,34 @@ QVariant TextBrowserViewer::loadOneResource(int type, const QUrl& name) {
   }
 
   // Resources are enabled and we already have the resource.
-  QByteArray resource_data = m_loadedResources.value(resolved_name);
+  int acceptable_width = int(width() * ACCEPTABLE_IMAGE_PERCENTUAL_WIDTH);
+
+  QMap<int, QByteArray>& resource_data_all_sizes = m_loadedResources[resolved_name];
   QImage img;
 
-  if (resource_data.isEmpty()) {
+  qDebugNN << LOGSEC_GUI << "Picture" << QUOTE_W_SPACE(name)
+           << "has these sizes cached:" << NONQUOTE_W_SPACE_DOT(resource_data_all_sizes.keys());
+
+  if (resource_data_all_sizes.isEmpty()) {
     img = m_placeholderImageError.toImage();
   }
   else {
-    img = QImage::fromData(m_loadedResources.value(resolved_name));
+    // Now, we either select specifically sized picture, or default one.
+    QByteArray resource_data;
+
+    if (resource_data_all_sizes.contains(acceptable_width)) {
+      // We have picture with this exact size. The picture was likely downsized
+      // to this size before.
+      resource_data = resource_data_all_sizes.value(acceptable_width);
+    }
+    else {
+      // We only have default size or not desired size. Return initial picture.
+      resource_data = resource_data_all_sizes.value(0);
+    }
+
+    img = QImage::fromData(resource_data);
   }
 
-  int acceptable_width = int(width() * ACCEPTABLE_IMAGE_PERCENTUAL_WIDTH);
   int img_width = img.width();
 
   if (img_width > acceptable_width) {
@@ -109,9 +126,18 @@ QVariant TextBrowserViewer::loadOneResource(int type, const QUrl& name) {
     QByteArray save_arr;
     QBuffer save_buf(&save_arr, this);
 
-    if (img.save(&save_buf, "PNG", 100)) {
+    if (img.save(&save_buf, "JPG", 100)) {
       save_buf.close();
-      m_loadedResources.insert(resolved_name, save_arr);
+
+      /*
+      IOFactory::writeFile(QSL("%1%2.jpg")
+                             .arg(name.toString(QUrl::ComponentFormattingOption::FullyEncoded),
+                                  QString::number(acceptable_width))
+                             .remove(QRegularExpression(":|\\/")),
+                           save_arr);
+*/
+
+      resource_data_all_sizes.insert(acceptable_width, save_arr);
     }
     else {
       qWarningNN << LOGSEC_GUI << "Failed to save modified image" << QUOTE_W_SPACE(name) << "to cache.";
@@ -269,7 +295,11 @@ void TextBrowserViewer::loadMessages(const QList<Message>& messages, RootItem* r
   setHtml(html_messages.m_html, html_messages.m_baseUrl);
 
   QTextOption op;
-  op.setTextDirection(messages.at(0).m_isRtl ? Qt::LayoutDirection::RightToLeft : Qt::LayoutDirection::LeftToRight);
+  op.setTextDirection((messages.at(0).m_rtlBehavior == RtlBehavior::Everywhere ||
+                       messages.at(0).m_rtlBehavior == RtlBehavior::EverywhereExceptFeedList ||
+                       messages.at(0).m_rtlBehavior == RtlBehavior::OnlyViewer)
+                        ? Qt::LayoutDirection::RightToLeft
+                        : Qt::LayoutDirection::LeftToRight);
   document()->setDefaultTextOption(op);
 
   emit loadingFinished(true);
@@ -544,12 +574,19 @@ void TextBrowserViewer::resourceDownloaded(const QUrl& url,
                                            int http_code,
                                            const QByteArray& contents) {
   Q_UNUSED(http_code)
+  if (!m_loadedResources.contains(url)) {
+    m_loadedResources.insert(url, QMap<int, QByteArray>());
+  }
+
+  QMap<int, QByteArray>& resource_data_all_sizes = m_loadedResources[url];
+
+  resource_data_all_sizes.clear();
 
   if (status == QNetworkReply::NetworkError::NoError) {
-    m_loadedResources.insert(url, contents);
+    resource_data_all_sizes.insert(0, contents);
   }
   else {
-    m_loadedResources.insert(url, {});
+    resource_data_all_sizes.insert(0, {});
   }
 
   downloadNextNeededResource();
