@@ -97,20 +97,6 @@ Application::Application(const QString& id, int& argc, char** argv, const QStrin
 #endif
 #endif
 
-  /*
-  QString aa = "Fri, 12 Apr 2024 5:23:57 GMT";
-  QDateTimeParser par(QMetaType::QDateTime, QDateTimeParser::FromString, QCalendar());
-
-  par.setDefaultLocale(QLocale::c());
-
-  QString st = "ddd, dd MMM yyyy H:m:s";
-  bool parsed = par.parseFormat(st);
-  QDateTime dt;
-  par.fromString(aa, &dt);
-
-  // QDateTime tim = QDateTime::fromString(aa, form);
-  QString check = dt.toString();
-*/
   QString custom_ua;
 
   parseCmdArgumentsFromMyInstance(raw_cli_args, custom_ua);
@@ -188,7 +174,8 @@ Application::Application(const QString& id, int& argc, char** argv, const QStrin
   // and skin.
   m_icons->setupSearchPaths();
   m_icons->loadCurrentIconTheme();
-  m_skins->loadCurrentSkin(usingLite());
+
+  reloadCurrentSkin(false);
 
   if (m_toastNotifications != nullptr) {
     connect(m_toastNotifications,
@@ -284,10 +271,13 @@ Application::Application(const QString& id, int& argc, char** argv, const QStrin
   if (isFirstRun()) {
     m_notifications->save({Notification(Notification::Event::GeneralEvent, true),
                            Notification(Notification::Event::NewUnreadArticlesFetched,
+                                        true,
+                                        false,
                                         true,
                                         QSL("%1/notify.wav").arg(SOUNDS_BUILTIN_DIRECTORY)),
                            Notification(Notification::Event::NewAppVersionAvailable, true),
                            Notification(Notification::Event::LoginFailure, true),
+                           Notification(Notification::Event::ArticlesFetchingError, true),
                            Notification(Notification::Event::NodePackageUpdated, true),
                            Notification(Notification::Event::NodePackageFailedToUpdate, true)},
                           settings());
@@ -300,8 +290,17 @@ Application::Application(const QString& id, int& argc, char** argv, const QStrin
 
   setupWorkHorsePool();
 
+#if QT_VERSION >= 0x060100 // Qt >= 6.1.0
+  QSslSocket::setActiveBackend(QSL("openssl"));
+#endif
+
   qDebugNN << LOGSEC_CORE << "Platform:" << QUOTE_W_SPACE_DOT(QGuiApplication::platformName());
   qDebugNN << LOGSEC_CORE << "SQLite version:" << QUOTE_W_SPACE_DOT(SQLITE_VERSION);
+
+#if QT_VERSION >= 0x060100 // Qt >= 6.1.0
+  qDebugNN << LOGSEC_CORE << "OpenSSL backends:" << QUOTE_W_SPACE_DOT(QSslSocket::availableBackends());
+#endif
+
   qDebugNN << LOGSEC_CORE << "OpenSSL version:" << QUOTE_W_SPACE_DOT(QSslSocket::sslLibraryVersionString());
   qDebugNN << LOGSEC_CORE << "OpenSSL supported:" << QUOTE_W_SPACE_DOT(QSslSocket::supportsSsl());
   qDebugNN << LOGSEC_CORE << "Global thread pool has"
@@ -333,12 +332,11 @@ void Application::performLogging(QtMsgType type, const QMessageLogContext& conte
   }
 
   if (!s_customLogFile.isEmpty()) {
-    QFile log_file(s_customLogFile);
+    static QFile* log_file = new QFile(s_customLogFile);
 
-    if (log_file.open(QFile::OpenModeFlag::Append | QFile::OpenModeFlag::Unbuffered)) {
-      log_file.write(console_message.toUtf8());
-      log_file.write(QSL("\r\n").toUtf8());
-      log_file.close();
+    if (log_file->isOpen() || log_file->open(QFile::OpenModeFlag::Append | QFile::OpenModeFlag::Unbuffered)) {
+      log_file->write(console_message.toUtf8());
+      log_file->write(QSL("\r\n").toUtf8());
     }
   }
 
@@ -361,8 +359,7 @@ void Application::reactOnForeignNotifications() {
 
 void Application::hideOrShowMainForm() {
   // Display main window.
-  if (qApp->settings()->value(GROUP(GUI), SETTING(GUI::MainWindowStartsHidden)).toBool() &&
-      SystemTrayIcon::isSystemTrayDesired() && SystemTrayIcon::isSystemTrayAreaAvailable()) {
+  if (qApp->settings()->value(GROUP(GUI), SETTING(GUI::MainWindowStartsHidden)).toBool()) {
     qDebugNN << LOGSEC_CORE << "Hiding the main window when the application is starting.";
     mainForm()->switchVisibility(true);
   }
@@ -379,16 +376,7 @@ void Application::loadDynamicShortcuts() {
 void Application::offerPolls() const {
   /*
   if (isFirstRunCurrentVersion()) {
-    qApp->showGuiMessage(Notification::Event::GeneralEvent,
-                         {tr("%1 survey").arg(QSL(APP_NAME)),
-                          tr("Please, fill the survey."),
-                          QSystemTrayIcon::MessageIcon::Warning},
-                         {false, true, false},
-                         {tr("Go to survey"), [] {
-                            qApp->web()->openUrlInExternalBrowser(QSL("https://docs.google.com/forms/d/e/"
-                                                                      "1FAIpQLScQ_r_EwM6qojPsIMQHGdnSktU-WGHgporN69mpU-"
-                                                                      "Tvq8y7XQ/viewform?usp=sf_link"));
-                          }});
+    qApp->web()->openUrlInExternalBrowser(QSL("https://forms.gle/3CZm95W6vrBLfi5K9"));
   }
   */
 }
@@ -687,7 +675,12 @@ void Application::restoreDatabaseSettings(bool restore_database,
 SystemTrayIcon* Application::trayIcon() {
   if (m_trayIcon == nullptr) {
     if (qApp->settings()->value(GROUP(GUI), SETTING(GUI::MonochromeTrayIcon)).toBool()) {
-      m_trayIcon = new SystemTrayIcon(APP_ICON_MONO_PATH, APP_ICON_MONO_PLAIN_PATH, m_mainForm);
+      if (qApp->settings()->value(GROUP(GUI), SETTING(GUI::ColoredBusyTrayIcon)).toBool()) {
+        m_trayIcon = new SystemTrayIcon(APP_ICON_MONO_PATH, APP_ICON_PLAIN_PATH, m_mainForm);
+      }
+      else {
+        m_trayIcon = new SystemTrayIcon(APP_ICON_MONO_PATH, APP_ICON_MONO_PLAIN_PATH, m_mainForm);
+      }
     }
     else {
       m_trayIcon = new SystemTrayIcon(APP_ICON_PATH, APP_ICON_PLAIN_PATH, m_mainForm);
@@ -772,10 +765,16 @@ void Application::showGuiMessageCore(Notification::Event event,
                                      GuiMessageDestination dest,
                                      const GuiAction& action,
                                      QWidget* parent) {
+  bool show_dialog = true;
+
   if (m_notifications->areNotificationsEnabled()) {
     auto notification = m_notifications->notificationForEvent(event);
 
-    notification.playSound(this);
+    show_dialog = notification.dialogEnabled();
+
+    if (notification.soundEnabled()) {
+      notification.playSound(this);
+    }
 
     if (notification.balloonEnabled() && dest.m_tray) {
       if (notification.event() == Notification::Event::ArticlesFetchingStarted && m_mainForm != nullptr &&
@@ -804,7 +803,7 @@ void Application::showGuiMessageCore(Notification::Event event,
     }
   }
 
-  if (dest.m_messageBox || msg.m_type == QSystemTrayIcon::MessageIcon::Critical) {
+  if (show_dialog && (dest.m_messageBox || msg.m_type == QSystemTrayIcon::MessageIcon::Critical)) {
     // Tray icon or OSD is not available, display simple text box.
     MsgBox::show(parent == nullptr ? mainFormWidget() : parent,
                  QMessageBox::Icon(msg.m_type),
@@ -1183,7 +1182,8 @@ void Application::setupWorkHorsePool() {
 void Application::onAdBlockFailure() {
   qApp->showGuiMessage(Notification::Event::GeneralEvent,
                        {tr("AdBlock needs to be configured"),
-                        tr("AdBlock is not configured properly. Go to \"Settings\" -> \"Node.js\" and check "
+                        tr("AdBlock is not configured properly or failed to start. Go to \"Settings\" -> \"Node.js\" "
+                           "and check "
                            "if your Node.js is properly configured."),
                         QSystemTrayIcon::MessageIcon::Critical},
                        {true, true, false});
@@ -1191,6 +1191,10 @@ void Application::onAdBlockFailure() {
   qApp->settings()->setValue(GROUP(AdBlock), AdBlock::AdBlockEnabled, false);
 }
 
+void Application::reloadCurrentSkin(bool replace_existing_qss) {
+  m_skins->loadCurrentSkin(usingLite(), replace_existing_qss);
+}
+
 void Application::determineFirstRuns() {
   m_firstRunEver = settings()->value(GROUP(General), SETTING(General::FirstRun)).toBool();
   m_firstRunCurrentVersion =
@@ -1387,13 +1391,20 @@ void Application::fillCmdArgumentsParser(QCommandLineParser& parser) {
                                       .arg(MAX_THREADPOOL_THREADS),
                                     QSL("count"));
 
-  parser.addOptions({
-    help, version, log_file, custom_data_folder, disable_singleinstance, disable_only_debug, disable_debug,
+  parser.addOptions({help,
+                     version,
+                     log_file,
+                     custom_data_folder,
+                     disable_singleinstance,
+                     disable_only_debug,
+                     disable_debug,
 #if defined(NO_LITE)
-      force_lite,
+                     force_lite,
 #endif
-      forced_style, adblock_port, custom_ua, custom_threads
-  });
+                     forced_style,
+                     adblock_port,
+                     custom_ua,
+                     custom_threads});
   parser.addPositionalArgument(QSL("urls"),
                                QSL("List of URL addresses pointing to individual online feeds which should be added."),
                                QSL("[url-1 ... url-n]"));
