@@ -15,6 +15,8 @@
 DKEY WebEngineAttributes::ID = "web_engine_attributes";
 #endif
 
+DKEY FileDialogPaths::ID = "file_dialog_paths";
+
 DKEY DialogGeometries::ID = "dialog_geometries";
 
 // Media player.
@@ -31,7 +33,7 @@ DKEY Node::ID = "nodejs";
 
 DKEY Node::NodeJsExecutable = QSL("nodejs_executable_") + OS_ID;
 
-#if defined(Q_OS_WIN) || defined(Q_OS_OS2)
+#if (defined(Q_OS_WIN) && !defined(BUILD_MSYS2)) || defined(Q_OS_OS2)
 DVALUE(QString) Node::NodeJsExecutableDef = "node.exe";
 #else
 DVALUE(QString) Node::NodeJsExecutableDef = "node";
@@ -39,7 +41,7 @@ DVALUE(QString) Node::NodeJsExecutableDef = "node";
 
 DKEY Node::NpmExecutable = QSL("npm_executable_") + OS_ID;
 
-#if defined(Q_OS_WIN)
+#if defined(Q_OS_WIN) && !defined(BUILD_MSYS2)
 DVALUE(QString) Node::NpmExecutableDef = "npm.cmd";
 #elif defined(Q_OS_OS2)
 DVALUE(QString) Node::NpmExecutableDef = "npm.exe";
@@ -98,6 +100,12 @@ DVALUE(char*) Feeds::CountFormatDef = "(%unread)";
 DKEY Feeds::EnableTooltipsFeedsMessages = "show_tooltips";
 DVALUE(bool) Feeds::EnableTooltipsFeedsMessagesDef = true;
 
+DKEY Feeds::StrikethroughDisabledFeeds = "strikethrough_disabled_feeds";
+DVALUE(bool) Feeds::StrikethroughDisabledFeedsDef = true;
+
+DKEY Feeds::PauseFeedFetching = "pause_feed_fetching";
+DVALUE(bool) Feeds::PauseFeedFetchingDef = false;
+
 DKEY Feeds::AutoUpdateInterval = "auto_update_interval";
 DVALUE(int) Feeds::AutoUpdateIntervalDef = DEFAULT_AUTO_UPDATE_INTERVAL;
 
@@ -116,9 +124,6 @@ DVALUE(bool) Feeds::FeedsUpdateOnStartupDef = false;
 DKEY Feeds::FeedsUpdateStartupDelay = "feeds_update_on_startup_delay";
 DVALUE(double) Feeds::FeedsUpdateStartupDelayDef = STARTUP_UPDATE_DELAY;
 
-DKEY Feeds::ShowOnlyUnreadFeeds = "show_only_unread_feeds";
-DVALUE(bool) Feeds::ShowOnlyUnreadFeedsDef = false;
-
 DKEY Feeds::SortAlphabetically = "sort_alphabetically";
 DVALUE(bool) Feeds::SortAlphabeticallyDef = false;
 
@@ -217,6 +222,9 @@ DVALUE(int) Messages::ArticleListPaddingDef = -1;
 DKEY Messages::MultilineArticleList = "multiline_article_list";
 DVALUE(bool) Messages::MultilineArticleListDef = false;
 
+DKEY Messages::SwitchArticleListRtl = "switch_article_list_rtl";
+DVALUE(bool) Messages::SwitchArticleListRtlDef = true;
+
 DKEY Messages::UseCustomTime = "use_custom_time";
 DVALUE(bool) Messages::UseCustomTimeDef = false;
 
@@ -258,6 +266,9 @@ DVALUE(bool) CustomSkinColors::EnabledDef = false;
 // GUI.
 DKEY GUI::ID = "gui";
 
+DKEY GUI::FeedViewState = "feed_view_state";
+DVALUE(QString) GUI::FeedViewStateDef = QString();
+
 DKEY GUI::MessageViewState = "msg_view_state";
 DVALUE(QString) GUI::MessageViewStateDef = QString();
 
@@ -287,8 +298,8 @@ DVALUE(int) GUI::HeightRowFeedsDef = -1;
 
 DKEY GUI::FeedsToolbarActions = "feeds_toolbar";
 DVALUE(char*)
-GUI::FeedsToolbarActionsDef =
-  "m_actionUpdateAllItems,m_actionStopRunningItemsUpdate,m_actionMarkAllItemsRead,spacer,search";
+GUI::FeedsToolbarActionsDef = "m_actionUpdateAllItems,m_actionStopRunningItemsUpdate,m_actionPauseFeedFetching,m_"
+                              "actionMarkAllItemsRead,filter,spacer,search";
 
 DKEY GUI::StatusbarActions = "status_bar";
 DVALUE(char*)
@@ -356,6 +367,9 @@ DVALUE(bool) GUI::HideMainWindowWhenMinimizedDef = false;
 DKEY GUI::MonochromeTrayIcon = "monochrome_tray_icon";
 DVALUE(bool) GUI::MonochromeTrayIconDef = false;
 
+DKEY GUI::ColoredBusyTrayIcon = "colored_busy_tray_icon";
+DVALUE(bool) GUI::ColoredBusyTrayIconDef = false;
+
 DKEY GUI::ForcedSkinColors = "forced_skin_colors";
 DVALUE(bool) GUI::ForcedSkinColorsDef = true;
 
@@ -614,6 +628,7 @@ SettingsProperties Settings::determineProperties() {
   SettingsProperties properties;
 
   properties.m_settingsSuffix = QDir::separator() + QSL(APP_CFG_PATH) + QDir::separator() + QSL(APP_CFG_FILE);
+
   const QString app_path = qApp->userDataAppFolder();
   const QString home_path = qApp->userDataHomeFolder();
   const QString custom_path = qApp->customDataFolder();
@@ -624,10 +639,10 @@ SettingsProperties Settings::determineProperties() {
     properties.m_baseDirectory = custom_path;
   }
   else {
-    // We will use PORTABLE settings only and only if it is available and NON-PORTABLE
+    // We will use PORTABLE settings only if it is available and NON-PORTABLE
     // settings was not initialized before.
-#if defined(Q_OS_UNIX)
-    // DO NOT use portable settings for *nix, it is really not used on that platform.
+#if defined(Q_OS_UNIX) || defined(BUILD_MSYS2)
+    // DO NOT use portable settings for *nix or MSYS2, it is really not used on those platforms.
     const bool will_we_use_portable_settings = false;
 #else
     const QString exe_path = qApp->applicationDirPath();
