@@ -23,7 +23,7 @@
 
 SkinFactory::SkinFactory(QObject* parent) : QObject(parent), m_styleIsFrozen(false), m_useSkinColors(false) {}
 
-void SkinFactory::loadCurrentSkin(bool lite) {
+void SkinFactory::loadCurrentSkin(bool lite, bool replace_existing_qss) {
   QList<QString> skin_names_to_try = {selectedSkinName(), QSL(APP_SKIN_DEFAULT)};
   bool skin_parsed;
   Skin skin_data;
@@ -34,7 +34,7 @@ void SkinFactory::loadCurrentSkin(bool lite) {
     skin_data = skinInfo(skin_name, lite, &skin_parsed);
 
     if (skin_parsed) {
-      loadSkinFromData(skin_data);
+      loadSkinFromData(skin_data, replace_existing_qss);
 
       // Set this 'Skin' object as active one.
       m_currentSkin = skin_data;
@@ -109,7 +109,7 @@ QPalette qt_fusionPalette(bool dark_appearance) {
   return fusion_palette;
 }
 
-void SkinFactory::loadSkinFromData(const Skin& skin) {
+void SkinFactory::loadSkinFromData(const Skin& skin, bool replace_existing_qss) {
 #if QT_VERSION >= 0x060500 // Qt >= 6.5.0
   auto system_color_scheme = qApp->styleHints()->colorScheme();
 
@@ -195,15 +195,26 @@ void SkinFactory::loadSkinFromData(const Skin& skin) {
 #endif
   }
 
+  QString qss_to_set = skin.m_rawForcedData;
+
   if (m_useSkinColors && !skin.m_rawData.isEmpty()) {
     if (qApp->styleSheet().simplified().isEmpty()) {
-      qApp->setStyleSheet(skin.m_rawData);
+      qss_to_set += QSL("\r\n") + skin.m_rawData;
     }
     else {
       qCriticalNN << LOGSEC_GUI
                   << "Skipped setting of application style and skin because there is already some style set.";
     }
   }
+
+  if (replace_existing_qss) {
+    qss_to_set = qss_to_set;
+  }
+  else {
+    qss_to_set = qApp->styleSheet() + QSL("\r\n") + qss_to_set;
+  }
+
+  qApp->setStyleSheet(qss_to_set);
 }
 
 void SkinFactory::setCurrentSkinName(const QString& skin_name) {
@@ -296,7 +307,11 @@ PreparedHtml SkinFactory::generateHtmlOfArticles(const QList<Message>& messages,
                                                      enclosures,
                                                      enclosure_images,
                                                      QString::number(message.m_id),
-                                                     message.m_isRtl ? QSL("rtl") : QSL("ltr")));
+                                                     (message.m_rtlBehavior == RtlBehavior::Everywhere ||
+                                                      message.m_rtlBehavior == RtlBehavior::EverywhereExceptFeedList ||
+                                                      message.m_rtlBehavior == RtlBehavior::OnlyViewer)
+                                                       ? QSL("rtl")
+                                                       : QSL("ltr")));
   }
 
   QString msg_contents =
@@ -486,6 +501,15 @@ Skin SkinFactory::skinInfo(const QString& skin_name, bool lite, bool* ok) const
       skin.m_enclosureMarkup =
         loadSkinFile(skin_folder_no_sep, lite, QSL("html_enclosure_every.html"), real_base_skin_folder);
       skin.m_rawData = loadSkinFile(skin_folder_no_sep, lite, QSL("qt_style.qss"), real_base_skin_folder);
+
+      try {
+        skin.m_rawForcedData =
+          loadSkinFile(skin_folder_no_sep, lite, QSL("qt_style_forced.qss"), real_base_skin_folder);
+      }
+      catch (...) {
+        qWarningNN << "Skin" << QUOTE_W_SPACE(skin_name) << "does not support forced QSS.";
+      }
+
       skin.m_adblocked = loadSkinFile(skin_folder_no_sep, lite, QSL("html_adblocked.html"), real_base_skin_folder);
       skin.m_skinFolder = skin_folder_no_sep;
 
@@ -634,6 +658,9 @@ QString SkinEnums::palleteColorText(PaletteColors col) {
     case SkinEnums::PaletteColors::Allright:
       return QObject::tr("OK-ish color");
 
+    case SkinEnums::PaletteColors::FgDisabledFeed:
+      return QObject::tr("disabled items");
+
     default:
       return {};
   }
